@@ -102,6 +102,8 @@ class OCWParser(object):
                 if loaded_json:
                     # Add the json file name (used for error reporting)
                     loaded_json["actual_file_name"] = str(json_index) + ".json"
+                    # The only representation we have of ordering is the file name
+                    loaded_json["order_index"] = int(json_index)
                     loaded_jsons.append(loaded_json)
                 else:
                     log.error("Failed to load %s", file_path)
@@ -194,6 +196,7 @@ class OCWParser(object):
             if url_data:
                 url_data = url_data.split("ocw.mit.edu")[1]
             page_dict = {
+                "order_index": safe_get(j, "order_index"),
                 "uid": safe_get(j, "_uid"),
                 "parent_uid": safe_get(j, "parent_uid"),
                 "title": safe_get(j, "title"),
@@ -202,6 +205,7 @@ class OCWParser(object):
                 "short_url": safe_get(j, "id"),
                 "description": safe_get(j, "description"),
                 "type": safe_get(j, "_type"),
+                "is_image_gallery": safe_get(j, "is_image_gallery"),
                 "is_media_gallery": safe_get(j, "is_media_gallery"),
                 "file_location": safe_get(j, "_uid") + "_" + safe_get(j, "id") + ".html"
             }
@@ -212,7 +216,7 @@ class OCWParser(object):
 
         if not self.jsons:
             self.jsons = self.load_raw_jsons()
-        page_types = ["CourseHomeSection", "CourseSection", "DownloadSection", "ThisCourseAtMITSection"]
+        page_types = ["CourseHomeSection", "CourseSection", "DownloadSection", "ThisCourseAtMITSection", "SupplementalResourceSection"]
         pages = []
         for json_file in self.jsons:
             if json_file["_content_type"] == "text/html" and \
@@ -225,6 +229,7 @@ class OCWParser(object):
     def compose_media(self):
         def _compose_media_dict(j):
             return {
+                "order_index": safe_get(j, "order_index"),
                 "uid": safe_get(j, "_uid"),
                 "id": safe_get(j, "id"),
                 "parent_uid": safe_get(j, "parent_uid"),
@@ -253,6 +258,7 @@ class OCWParser(object):
         for j in self.jsons:
             if j and "inline_embed_id" in j and j["inline_embed_id"]:
                 temp = {
+                    "order_index": safe_get(j, "order_index"),
                     "title": j["title"],
                     "uid": j["_uid"],
                     "parent_uid": j["parent_uid"],
